This template shows off a simple interactive Dashboard, which allows you to
view the balance of a cryptocurrency wallet, the details of a cryptocurrency,
and a chart of the price of a cryptocurrency.

**The example is composed of four main components:**

1. BalanceCard: Displays the balance of a cryptocurrency wallet.
2. CryptoCard: Displays the details of a cryptocurrency.
3. CryptoChart: Displays a chart of the price of a cryptocurrency.
4. DashboardPage: Combines the BalanceCard, CryptoCard, and CryptoChart
   components and add some logic.

**The main takeaways are:**

-   How to create a simple interactive dashboard.
-   How to pass data between components.
-   How to populate your application with your own data.
-   How to fetch data from an API or Local Storage.
